diff --git a/MantidQt/CustomInterfaces/inc/MantidQtCustomInterfaces/EnggDiffraction/EnggDiffractionQtTabFitting.ui b/MantidQt/CustomInterfaces/inc/MantidQtCustomInterfaces/EnggDiffraction/EnggDiffractionQtTabFitting.ui
index fe234039b3cc25d52f0aaf9b0d2cb5504d9603ce..0e301db4582f34feb679cddf188a9e8858244651 100644
--- a/MantidQt/CustomInterfaces/inc/MantidQtCustomInterfaces/EnggDiffraction/EnggDiffractionQtTabFitting.ui
+++ b/MantidQt/CustomInterfaces/inc/MantidQtCustomInterfaces/EnggDiffraction/EnggDiffractionQtTabFitting.ui
@@ -363,6 +363,9 @@
         </item>
         <item>
          <widget class="QPushButton" name="pushButton_select_peak">
+          <property name="enabled">
+           <bool>false</bool>
+          </property>
           <property name="text">
            <string>Select Peak</string>
           </property>
diff --git a/MantidQt/CustomInterfaces/src/EnggDiffraction/EnggDiffractionViewQtGUI.cpp b/MantidQt/CustomInterfaces/src/EnggDiffraction/EnggDiffractionViewQtGUI.cpp
index 56e2385b91d2145ef2005e701f660bfe3c0126c6..10341f8efb2fa703c40816962f8072453e3174b0 100644
--- a/MantidQt/CustomInterfaces/src/EnggDiffraction/EnggDiffractionViewQtGUI.cpp
+++ b/MantidQt/CustomInterfaces/src/EnggDiffraction/EnggDiffractionViewQtGUI.cpp
@@ -777,8 +777,9 @@ void EnggDiffractionViewQtGUI::dataCurvesFactory(
 
   m_uiTabFitting.dataPlot->replot();
   m_zoomTool->setZoomBase();
   // enable zoom after the plotting on graph
   setZoomTool(true);
+  m_uiTabFitting.pushButton_select_peak->setEnabled(true);
   data.clear();
 }
@@ -777,8 +777,9 @@ void EnggDiffractionViewQtGUI::dataCurvesFactory(
   m_uiTabFitting.dataPlot->replot();
   m_zoomTool->setZoomBase();
-  // enable zoom after the plotting on graph
+  // enable zoom & select peak btn after the plotting on graph
   setZoomTool(true);